@@ -26,7 +26,7 @@
             upstream-doc))
 
 (define (abs-top-srcdir)
-  "/home/wingo/src/guile-opengl")
+  "/home/dave/Code/guile-opengl")
 
 (define (upstream-doc)
-  "/home/wingo/src/guile-opengl/upstream-doc")
+  "/home/dave/Code/guile-opengl/upstream-doc")
